import os
from os.path import join
import sys
import json
from .utils import *

class ConfigStore:
    
    

    def __init__(self, name, defaults={}, globalConfigPath=False):
        self.name = name
        self.defaults = defaults
        self.globalConfigPath = globalConfigPath
        
        self.configDir = getConfigDir()

        if self.globalConfigPath:
            self.pathPrefix = join(name, 'config.json')
            pathEntry = name
        else:
            self.pathPrefix = join('configstore', '{}.json'.format(name))
            pathEntry = 'configstore'

        self.path = join(self.configDir, self.pathPrefix)
        # self.all = {}
        createConfig(self.path, self.defaults, pathEntry=pathEntry)
        self.Object = loadConfigs(self.path)
        self.size = getConfigSize(self.path)

    
    def all(self, Object=None):
        if Object:
            self.set(Object)
        
        jsonConfigs = loadConfigs(self.path)
        return jsonConfigs
        
    def get(self, key):
        value = getConfigs(self.path, key)
        return value
    
    def set(self, key, value=None):
        if isinstance(key, dict):
            setObject = key
            setConfigs(self.path, Object=setObject)
        else:
            if not value:
                raise KeyError("KeyError: param value not provided")
            
            setConfigs(self.path, key=key, value=value)

    def has(self, key):
        return hasConfigs(self.path, key)

    def delete(self, key):
        deleteConfigs(self.path, key)
    
    def clear(self):
        clearConfigs(self.path)





from setuptools import setup, find_packages
from os import path
import os

here = path.abspath(path.dirname(__file__))

# long description from the README file

def read(filename):
    return open(os.path.join(os.path.dirname(__file__), filename)).read()


long_description = read('README.md')

setup(
    name='pyconfigstore3',
    version='1.0.1',
    description=(
        'A Python module for handling config files. It helps handles persist config files and also giving the ability to set, get, update and delete config settings'
          ' its based on Configstore.js'
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    license='MIT',
    url='https://github.com/CITGuru/ConfigStore',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: User Interfaces',
        'Topic :: Software Development :: '
        'Libraries :: Application Frameworks',
    ],
    keywords='config, settings, .env, json, settings, configstore',
    packages=find_packages(exclude=['docs', 'tests*']),
    include_package_data=True,
    author='Oyetoke Toby',
    download_url='https://github.com/CITGuru/ConfigStore/archive/1.0.0.tar.gz',
    install_requires=[],
    author_email='oyetoketoby80@gmail.com',
)
